import datetime
from dateutil import tz
from django.db import models
from django.utils import timezone
from django.conf import settings
try:
    from south.modelsinspector import add_introspection_rules
    add_introspection_rules([], ["^datetimeutc\.fields\.DateTimeUTCField"])
except ImportError:
    pass


class DateTimeUTCField(models.DateTimeField):
    """Creates a DB timestamp field that is TZ naive."""

    description = "Date (with time and no time zone)"

    __metaclass__ = models.SubfieldBase

    def __init__(self, *args, **kwargs):
        super(DateTimeUTCField, self).__init__(*args, **kwargs)

    def db_type(self, connection):
        if connection.settings_dict['ENGINE'] == 'django.db.backends.mysql':
            return 'datetime'
        else:
            return 'timestamp'

    def to_python(self, value):
        if value is None:
            return value
        if isinstance(value, datetime.datetime):
            if settings.USE_TZ and timezone.is_naive(value):
                return value.replace(tzinfo=tz.gettz('UTC'))
            return value
        return super(DateTimeUTCField, self).to_python(value)

    def get_prep_value(self, value):
        if isinstance(value, datetime.datetime):
            return value.astimezone(tz.gettz('UTC'))
        return value



from setuptools import setup
from os.path import join
from os.path import dirname


version = __import__('datetimeutc').__version__

LONG_DESCRIPTION = """
django-datetime-utc provides DateTimeUTCField, a naive datetime model field.
In PostgreSQL this translates to the field 'timestamp without time zone'."""

def long_description():
    try:
        return open(join(dirname(__file__), 'README.rst')).read()
    except IOError:
        return LONG_DESCRIPTION

setup(
    name="django-datetime-utc",
    version=version,
    description="Django UTC datetime model field - timestamp without time zone",
    long_description=long_description(),
    url='https://github.com/pixeldomain/django-datetime-utc',
    author='Darren O\'Neill',
    author_email='darren@pixeldomain.co.uk',
    license='MIT',
    classifiers=[
        'Framework :: Django',
        'Environment :: Web Environment',
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Internet',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
    keywords='django, timestamp without time zone, utc, datetime',
    packages=['datetimeutc'],
    install_requires = ['Django>=1.5.0', 'python-dateutil'],
)
